@@ -1,9 +1,9 @@
 package Pod::Weaver::Plugin::WordList;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-09-15'; # DATE
+our $DATE = '2021-05-17'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-WordList'; # DIST
-our $VERSION = '0.063'; # VERSION
+our $VERSION = '0.064'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -50,11 +50,12 @@ sub _process_module {
         push @pod, " my \$wl = $package->new;\n\n";
 
         push @pod, " # Pick a (or several) random word(s) from the list\n";
-        push @pod, " my \$word = \$wl->pick;\n";
-        push @pod, " my \@words = \$wl->pick(3);\n\n";
+        push @pod, " my (\$word) = \$wl->pick;\n";
+        push @pod, " my (\$word) = \$wl->pick(1);  # ditto\n";
+        push @pod, " my \@words  = \$wl->pick(3);  # no duplicates\n\n";
 
         push @pod, " # Check if a word exists in the list\n";
-        push @pod, " if (\$wl->word_exists('foo')) { ... }\n\n";
+        push @pod, " if (\$wl->word_exists('foo')) { ... }  # case-sensitive\n\n";
 
         push @pod, " # Call a callback for each word\n";
         push @pod, " \$wl->each_word(sub { my \$word = shift; ... });\n\n";
@@ -63,7 +64,7 @@ sub _process_module {
         push @pod, " my \$first_word = \$wl->first_word;\n";
         push @pod, " while (defined(my \$word = \$wl->next_word)) { ... }\n\n";
 
-        push @pod, " # Get all the words\n";
+        push @pod, " # Get all the words (beware, some wordlists are *huge*)\n";
         push @pod, " my \@all_words = \$wl->all_words;\n\n";
 
         $self->add_text_to_section(
@@ -194,7 +195,7 @@ Pod::Weaver::Plugin::WordList - Plugin to use when building WordList::* distribu
 
 =head1 VERSION
 
-This document describes version 0.063 of Pod::Weaver::Plugin::WordList (from Perl distribution Pod-Weaver-Plugin-WordList), released on 2020-09-15.
+This document describes version 0.064 of Pod::Weaver::Plugin::WordList (from Perl distribution Pod-Weaver-Plugin-WordList), released on 2021-05-17.
 
 =head1 SYNOPSIS
 
@@ -227,7 +228,7 @@ Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Wo
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Plugin-WordList>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-WordList/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -245,7 +246,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
